@@ -28,7 +28,7 @@ import re
 import json
 import errno
 
-__version__ = "1.5.4"
+__version__ = "1.5.6"
 
 
 class IfState():
@@ -67,7 +67,7 @@ class IfState():
         except ValidationError as ex:
             if len(ex.path) > 0:
                 path = ["$"]
-                for i, p in enumerate(ex.path):
+                for i, p in enumerate(ex.absolute_path):
                     if type(p) == int:
                         path.append("[{}]".format(p))
                     else:
@@ -357,8 +357,12 @@ class IfState():
                     # unsupported link type, fallback to raw encoding
                     if data is not None and type(data) != str:
                         for k, v in data['attrs']:
-                            if k != "UNKNOWN" and type(data) in [str, int] and v != 0:
-                                ifs_link['link'][ipr_link.nla2name(k)] = v
+                            if k not in ['UNKNOWN', 'IFLA_VLAN_FLAGS']:
+                                attr = ipr_link.nla2name(k)
+                                if attr in Link.attr_value_maps:
+                                    ifs_link['link'][attr] = Link.attr_value_maps[attr].get(v, v)
+                                else:
+                                    ifs_link['link'][attr] = v
                 else:
                     ifs_link['link']['kind'] = 'physical'
                     addr = ipr_link.get_attr('IFLA_ADDRESS')
@@ -374,10 +378,16 @@ class IfState():
                     if not businfo is None:
                         ifs_link['link']['businfo'] = businfo
 
-                master = ipr_link.get_attr('IFLA_MASTER')
-                if master is not None:
-                    ifs_link['link']['master'] = ipr.get_ifname_by_index(
-                        master)
+                for attr in ['link', 'master', 'gre_link', 'ip6gre_link', 'vxlan_link', 'xfrm_link']:
+                    ref = ipr_link.get_attr('IFLA_{}'.format(attr.upper()))
+                    if ref is not None:
+                        try:
+                            ifs_link['link'][attr] = ipr.get_ifname_by_index(
+                                ref)
+                        except NetlinkError as err:
+                            logger.warning('lookup {} failed: {}'.format(
+                                attr, err.args[1]), extra={'iface': name})
+                            ifs_link['link'][attr] = ref
 
                 mtu = ipr_link.get_attr('IFLA_MTU')
                 if not mtu is None and not mtu in [1500, 65536]:
